@@ -1,4 +1,4 @@
-#! /usr/bin/python3
+#!/usr/bin/python3
 
 import gi
 gi.require_version('AccountsService', '1.0')
@@ -27,6 +27,10 @@ class AccountsServiceClient(GObject.Object):
                                            self.on_accounts_service_loaded)
 
     def on_accounts_service_loaded(self, service, param):
+        trackers.con_tracker_get().disconnect(self.service,
+                                              "notify::is-loaded",
+                                              self.on_accounts_service_loaded)
+
         self.is_loaded = True
         self.emit("account-loaded")
 
@@ -35,11 +39,14 @@ class AccountsServiceClient(GObject.Object):
 
     def get_face_path(self):
         face_path = None
+        home_path = self.service.get_home_dir()
+        if home_path is None:
+            home_path = os.path.expanduser('~')
 
-        for path in [os.path.join(self.service.get_home_dir(), ".face"),
+        for path in [os.path.join(home_path, ".face"),
                      self.service.get_icon_file()]:
             if os.path.exists(path):
                 face_path = path
                 break
 
-        return face_path
\ No newline at end of file
+        return face_path
